# tst [![Português](images/BR.png)](README.pt-BR.md) [![English](images/US.png)](README.md)

TST is a set of command line tools that automate testing and
verification of computer programming exercises/assignments. TST
supports both input/output and script based tests. By default,
TST can be used with Python, Javascript (node) and Java. However,
it is easy to configure TST to support other programming
languages as well.

## License

This software is licensed under the terms of the AGPL 3.0
license. Please read the LICENSE file.


## Installation

TST tools were designed to be installed through pip in user space
(it works ok if you install it as root also). To install tst,
type:

```
pip3 install --user tst
```

You may also want to install a _pre-release_ version. In such
case, use the following command.

```
pip3 install --user --pre tst
```

